@@ -1,29 +1,14 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2016 Ivan Lakhtanov <ivan.lakhtanov@gmail.com>
-    Copyright (C) 2019 Alexander Semke <alexander.semke@web.de>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2016 Ivan Lakhtanov <ivan.lakhtanov@gmail.com>
+    SPDX-FileCopyrightText: 2019 Alexander Semke <alexander.semke@web.de>
+*/
 
 #include "juliabackend.h"
 #include "juliaextensions.h"
 #include "juliasession.h"
+#include "juliasettingswidget.h"
 #include "settings.h"
-#include "ui_settings.h"
 
 #include <QProcess>
 
@@ -149,10 +134,7 @@ bool JuliaBackend::requirementsFullfilled(QString* const reason) const
 
 QWidget* JuliaBackend::settingsWidget(QWidget *parent) const
 {
-    QWidget* widget = new QWidget(parent);
-    Ui::JuliaSettingsBase s;
-    s.setupUi(widget);
-    return widget;
+    return new JuliaSettingsWidget(parent, id());
 }
 
 KConfigSkeleton* JuliaBackend::config() const
